@@ -2,13 +2,14 @@
 """Expander core; essentially, how to apply a macro invocation."""
 
 __all__ = ["MacroExpansionError", "MacroExpanderMarker", "Done",
-           "BaseMacroExpander", "global_postprocess"]
+           "BaseMacroExpander", "global_postprocess",
+           "add_postprocessor", "remove_postprocessor"]
 
 from ast import AST, NodeTransformer
 from collections import ChainMap
 from contextlib import contextmanager
 from copy import deepcopy
-from typing import Any, Callable, Dict
+from typing import Any, Callable, Dict, List
 
 from .astfixers import fix_ctx, fix_locations
 from .markers import ASTMarker, delete_markers
@@ -22,6 +23,9 @@ from .utils import flatten, format_location
 # but as of 3.1.0, we skim over this detail.
 global_bindings: Dict[str, Callable[..., Any]] = {}
 
+# User function hook for `global_postprocess`.
+global_postprocessors: List[Callable[..., Any]] = []
+
 class MacroExpansionError(Exception):
     """Base class for errors specific to macro expansion.
 
@@ -363,8 +367,53 @@ def global_postprocess(tree):
     to Python's `compile`.
     """
     tree = delete_markers(tree, cls=MacroExpanderMarker)
+
     # A name macro, appearing as an assignment target, gets the wrong ctx,
     # because when expanding the name macro, the expander sees only the Name
     # node, and thus puts an `ast.Load` there as the ctx.
     tree = fix_ctx(tree, copy_seen_nodes=True)
+
+    # Run the user hooks, if any.
+    for custom_postprocessor in global_postprocessors:
+        tree = custom_postprocessor(tree)
+
     return tree
+
+def add_postprocessor(function):
+    """Add a custom postprocessor for the top-level expansion.
+
+    `function` must accept `AST` and `list` of `AST`, and return
+    the same type.
+
+    Custom postprocessors are automatically called by `global_postprocess`
+    (which is called just after macro expansion for a module ends), in the
+    order they were registered by calling `add_postprocessor`.
+
+    This e.g. allows a macro library to use its own `ASTMarker` subclasses
+    for internal communication between macros, and delete (only) its own
+    markers when done.
+
+    Put something like this somewhere in your library initialization code
+    (preferably somewhere it's easy to discover for someone reading your
+    code, such as in a package `__init__.py`):
+
+        from functools import partial
+
+        import mcpyrate.core
+        from mcpyrate.markers import delete_markers
+
+        _delete_my_markers = partial(delete_markers,
+                                     cls=MyCustomMarkerBase)
+        mcpyrate.core.add_postprocessor(_delete_my_markers)
+    """
+    if function not in global_postprocessors:
+        global_postprocessors.append(function)
+
+def remove_postprocessor(function):
+    """Remove a previously added custom postprocessor.
+
+    The `function` is the callable object that was registered as a
+    postprocessor using `add_postprocessor`.
+    """
+    if function in global_postprocessors:
+        global_postprocessors.remove(function)
